//===----------------------------------------------------------------------===//
//
// Debian paths declaration management
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef DEBIAN_PATH_H
#define DEBIAN_PATH_H

// Provides the debian revision
#define DEB_PATCHSETVERSION  "@DEB_PATCHSETVERSION@"

#endif
